{
Copyright (C) 2002-2020  Massimo Melina (www.rejetto.com)

This file is part of HFS ~ HTTP File Server.

    HFS is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HFS is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with HSG; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

Modified by Mars & SilentPliz - 2007/2012 - <silentpliz@gmail.com>
Internationalized & localized for HFS ~ HTTP File Server by SilentPliz - 2011-2013  <silentpliz@gmail.com>
}
{$INCLUDE defs.inc }
{$SetPEOptFlags $100 } //IMAGE_DLLCHARACTERISTICS_NX_COMPAT
program hfs;

uses
  FastMM4,
  gnugettext,  //add by SilentPliz
{$IFDEF EX_DEBUG}
  ftmExceptionForm,
{$ENDIF}  
  VCLFixPack,  //add by SilentPliz
  monoLib,
  Forms,
  windows,
  types,
  hslib,
  sysUtils,
  StrUtils,
  uFreeLocalizer,  
  main in 'main.pas' {mainFrm},
  newuserpassDlg in 'newuserpassDlg.pas' {newuserpassFrm},
  optionsDlg in 'optionsDlg.pas' {optionsFrm},
  utillib in 'utillib.pas',
  longinputDlg in 'longinputDlg.pas' {longinputFrm},
  folderKindDlg in 'folderKindDlg.pas' {folderKindFrm},
  shellExtDlg in 'shellExtDlg.pas' {shellExtFrm},
  diffDlg in 'diffDlg.pas' {diffFrm},
  classesLib in 'classesLib.pas',
  ipsEverDlg in 'ipsEverDlg.pas' {ipsEverFrm},
  parserLib in 'parserLib.pas',
  purgeDlg in 'purgeDlg.pas' {purgeFrm},
  listSelectDlg in 'listSelectDlg.pas' {listSelectFrm},
  filepropDlg in 'filepropDlg.pas' {filepropFrm},
  runscriptDlg in 'runscriptDlg.pas' {runScriptFrm},
  scriptLib in 'scriptLib.pas',
  Licence in 'Licence.pas' {Form1};  //add by SilentPliz

{$R *.res}

  procedure processSlaveParams(params:string);
  var
    ss: TStringDynArray;
  begin
  if mainfrm = NIL then exit;
  ss:=split(#13,params);
  processParams_before(ss);
  mainfrm.processParams_after(ss);
  end;

  function isSingleInstance():boolean;
  var
    params:TStringDynArray;
    ini, tpl:string;
  begin
  result:=FALSE;
  // the -i parameter affects loadCfg()
  params:=paramsAsArray();
  processParams_before(params, 'i');
  loadCfg(ini, tpl);
  chop('only-1-instance=', ini);
  if ini = '' then exit;
  ini:=chopLine(ini);
  result:=sameText(ini, 'yes');
  end; // isSingleInstance

begin
  mono.onSlaveParams:=processSlaveParams;
  if not holdingKey(VK_CONTROL) then
    begin
    if not mono.init('HttpFileServer') then
      begin
      msgDlg(_('Erreur monolib : ')+mono.error, MB_ICONERROR+MB_OK, _('ERREUR'));
      halt(1);
      end;
    if not mono.master and isSingleInstance() then
      begin
      mono.sendParams();
      exit;
      end;
    end;

begin  //add by SilentPliz
  if not DirectoryExists('locale') then
  if not CreateDir('locale') then
    raise Exception.Create(_('Impossible de creer')+' locale');

  if not DirectoryExists('locale\en') then
  if not CreateDir('locale\en') then
    raise Exception.Create(_('Impossible de creer')+' locale\en');

  if not DirectoryExists('locale\fr') then
  if not CreateDir('locale\fr') then
    raise Exception.Create(_('Impossible de creer')+' locale\fr');
	
  if not DirectoryExists('locale\ru') then
  if not CreateDir('locale\ru') then
   raise Exception.Create(_('Impossible de creer')+' locale\ru');
   
  if not DirectoryExists('locale\es') then
  if not CreateDir('locale\es') then
    raise Exception.Create(_('Impossible de creer')+' locale\es');
	
  if not DirectoryExists('locale\it') then
  if not CreateDir('locale\it') then
   raise Exception.Create(_('Impossible de creer')+' locale\it');
   
  if not DirectoryExists('locale\zh') then
  if not CreateDir('locale\zh') then
   raise Exception.Create(_('Impossible de creer')+' locale\zh');   
   
  if not DirectoryExists('locale\en\LC_MESSAGES') then
  if not CreateDir('locale\en\LC_MESSAGES') then
    raise Exception.Create(_('Impossible de creer')+' locale\en\LC_MESSAGES');

  if not DirectoryExists('locale\fr\LC_MESSAGES') then
  if not CreateDir('locale\fr\LC_MESSAGES') then
    raise Exception.Create(_('Impossible de creer')+' locale\fr\LC_MESSAGES');

  if not DirectoryExists('locale\ru\LC_MESSAGES') then
  if not CreateDir('locale\ru\LC_MESSAGES') then
    raise Exception.Create(_('Impossible de creer')+' locale\ru\LC_MESSAGES');
	
  if not DirectoryExists('locale\es\LC_MESSAGES') then
  if not CreateDir('locale\es\LC_MESSAGES') then
    raise Exception.Create(_('Impossible de creer')+' locale\es\LC_MESSAGES');

  if not DirectoryExists('locale\it\LC_MESSAGES') then
  if not CreateDir('locale\it\LC_MESSAGES') then
    raise Exception.Create(_('Impossible de creer')+' locale\it\LC_MESSAGES');

  if not DirectoryExists('locale\zh\LC_MESSAGES') then
  if not CreateDir('locale\zh\LC_MESSAGES') then
    raise Exception.Create(_('Impossible de creer')+' locale\zh\LC_MESSAGES');	
end;  //end add by SilentPliz

  {$IFDEF EX_DEBUG}initErrorHandler(format('HFS %s (%s)', [VERSION, VERSION_BUILD]));{$ENDIF}
  UseLanguage ('default');  //add by SilentPliz
  Application.Initialize();
  FreeLocalizer.AutoTranslate := True;
  FreeLocalizer.LanguageFile := 'hfs.lng';  
  Application.CreateForm(TmainFrm, mainFrm);
  Application.CreateForm(TnewuserpassFrm, newuserpassFrm);
  Application.CreateForm(ToptionsFrm, optionsFrm);
  Application.CreateForm(TdiffFrm, diffFrm);
  Application.CreateForm(TipsEverFrm, ipsEverFrm);
  Application.CreateForm(TrunScriptFrm, runScriptFrm);
  Application.CreateForm(TForm1, Form1);  //add by SilentPliz
  mainfrm.finalInit();
  Application.Run;
  {$IFDEF EX_DEBUG}closeErrorHandler();{$ENDIF}
end.
